*******************
Authors and Credits
*******************

Astropy Project Coordinators
============================

* Perry Greenfield
* Thomas Robitaille
* Erik Tollerud


Core Package Contributors
=========================

* Shailesh Ahuja
* Tom Aldcroft
* Kyle Barbary
* Geert Barentsen
* Paul Barrett
* Andreas Baumbach
* Chris Beaumont
* Daniel Bell
* Francesco Biscani
* Thompson Le Blanc
* Christopher Bonnett
* Joseph Jon Booker
* Médéric Boquien
* Azalee Bostroem
* Matthew Bourque
* Larry Bradley
* Gustavo Bragança
* Erik M. Bray
* Eli Bressert
* Hugo Buddelmeijer
* Mihai Cara
* Mabry Cervin
* Pritish Chakraborty
* Alex Conley
* Jean Connelly
* Simon Conseil
* Ryan Cooke
* Matthew Craig
* Steven Crawford
* Neil Crighton
* Kelle Cruz
* Daniel Datsev
* Matt Davis
* Christoph Deil
* Nadia Dencheva
* Jörg Dietrich
* Axel Donath
* Michael Droettboom
* Jonathan Eisenhamer
* Zach Edwards
* Thomas Erben
* Henry Ferguson
* Jonathan Foster
* Ryan Fox
* Lehman Garrison
* Simon Gibbons
* Adam Ginsburg
* Christoph Gohlke
* Perry Greenfield
* Dylan Gregersen
* Frédéric Grollier
* Karan Grover
* Kevin Gullikson
* Hans Moritz Günther
* Alex Hagen
* Michael Hoenig
* Emma Hogan
* Chris Hanley
* JC Hsu
* Anthony Horton
* Eric Jeschke
* Sarah Kendrew
* Marten van Kerkwijk
* Wolfgang Kerzendorf
* Lennard Kiehl
* Rashid Khan
* Dominik Klaes
* Kacper Kowalik
* Roban Hultman Kramer
* Arne de Laat
* Antony Lee
* Simon Liedtke
* Pey Lian Lim
* Joseph Long
* Aaron Meisner
* Serge Montagnac
* José Sabater Montes
* Michael Mueller
* Stuart Mumford
* Demitri Muna
* Prasanth Nair
* Bogdan Nicula
* Joe Philip Ninan
* Bryce Nordgren
* Miruna Oprescu
* Luigi Paioro
* Asish Panda
* Madhura Parikh
* Sergio Pascual
* Rohit Patil
* David Perez-Suarez
* Ray Plante
* Adrian Price-Whelan
* J. Xavier Prochaska
* David Pérez-Suárez
* QuanTakeuchi
* Tanuj Rastogi
* Thomas Robitaille
* Juan Luis Cano Rodríguez
* Evert Rol
* Alex Rudy
* Joseph Ryan
* Eloy Salinas
* Gerrit Schellenberger
* David Shiga
* David Shupe
* Jonathan Sick
* Leo Singer
* Brigitta Sipocz
* Shivan Sornarajah
* Shantanu Srivastava
* Ole Streicher
* Bernardo Sulzbach
* James Taylor
* Jeff Taylor
* Kirill Tchernyshyov
* Víctor Terrón
* Erik Tollerud
* James Turner
* Miguel de Val-Borro
* Jonathan Whitmore
* Lisa Walter
* Benjamin Alan Weaver
* Jonathan Whitmore
* Julien Woillez
* Víctor Zabalza

Other Credits
=============

* Kyle Barbary for designing the Astropy logos and documentation themes.
* Andrew Pontzen and the `pynbody <https://github.com/pynbody/pynbody>`_ team
  (For code that grew into :mod:`astropy.units`)
* Everyone on `astropy-dev <http://groups.google.com/group/astropy-dev>`_
  and the `astropy mailing list <http://mail.scipy.org/mailman/listinfo/astropy>`_
  for contributing to many discussions and decisions!

(If you have contributed to the Astropy project and your name is missing,
please send an email to the coordinators, or
`open a pull request for this page <https://github.com/astropy/astropy/edit/master/docs/credits.rst>`_
in the `astropy repository <https://github.com/astropy/astropy>`_)
